/*
 * Licensed Materials - Property of IBM
 *
 * com.ibm.etools.c
 *
 *  Copyright IBM Corporation 2004. All Rights Reserved. 
 *
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 */

package com.ibm.etools.c.plugin;

/**
 * Insert the type's description here. Creation date: (9/4/2001 11:06:01 AM)
 * 
 * @author: Bernhard Jakob, IBM
 */
import java.util.Hashtable;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

import org.eclipse.core.runtime.Platform;
import org.eclipse.core.runtime.Plugin;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.osgi.framework.BundleContext;

import com.ibm.etools.logging.util.IPluginHelper;
import com.ibm.etools.logging.util.MsgLogger;
import com.ibm.etools.logging.util.PluginHelperImpl;

public class CPlugin extends AbstractUIPlugin implements IPluginHelper {

    public static final String copyright = "Licensed Material - Property of IBM\n com.ibm.etools.c\n(C) Copyright IBM Corp. 2004 - All Rights Reserved.\nUS Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp."; //$NON-NLS-1$

    /*
     * Plugin.xml constants
     */
    public static final String PLUGIN_ID = "com.ibm.etools.c";//$NON-NLS-1$

    // plugin's resource bundle
    private static ResourceBundle resourceBundle;

    /**
     * Keep track of the singleton.
     */
    private static CPlugin fieldPlugin;

    /**
     * CPlugin constructor comment.
     */
    public CPlugin() {
        super();

        // Remember the static instance.
        if (fieldPlugin == null) {
            fieldPlugin = this;
        }
    }

    /**
     * Returns the plugin singleton.
     */
    public static CPlugin getDefault() {
        return fieldPlugin;
    }

    /**
     * Get the singleton instance.
     */
    public static CPlugin getPlugin() {
        return fieldPlugin;
    }

    /**
     * 
     * Returns the string from the plugin's resource bundle, or 'key' if not
     * found.
     * 
     * @param String
     *            key for string to be returned from plugins's resource bundle
     * 
     * @return String from plugin's resource bundle
     *  
     */
    public static String getResourceString(String key) {
        ResourceBundle bundle = CPlugin.getDefault().getResourceBundle();

        try {
            return (bundle != null) ? bundle.getString(key) : key;
        } catch (MissingResourceException e) {
            return key;
        }
    }

    /**
     * 
     * Returns the plugin's resource bundle - instanciate plugin's resource
     * bundle if not already done
     * 
     * @return ResourceBundle plugin's resource bundle
     *  
     */
    public ResourceBundle getResourceBundle() {
        if (resourceBundle == null) {
            resourceBundle = Platform.getResourceBundle(getBundle());
        }

        return resourceBundle;
    }

    /**
     * Returns the workbench used by the example
     * 
     * This method is internal to the plugin and must not be called by any other
     * plugins.
     */
    public IWorkbench getWorkbench() {
        return PlatformUI.getWorkbench();
    }

    public void setMsgLoggerConfig(Hashtable msgLoggerConfig) {
        getMsgLogger().setMsgLoggerConfig(msgLoggerConfig);
    }

    public Hashtable getMsgLoggerConfig(Plugin plugin) {
        return (new PluginHelperImpl().getMsgLoggerConfig(plugin));
    }

    public Hashtable getMsgLoggerConfig() {
        return (getMsgLoggerConfig(this));
    }

    public MsgLogger getMsgLogger() {
        return null;
    }

    /**
     * @see com.ibm.etools.ctc.plugin.BasePlugin
     */
    public void initialize() throws org.eclipse.core.runtime.CoreException {
    }

    public static String getInstallationDirectory() {
        try {
            return Platform.resolve(fieldPlugin.getBundle().getEntry("/")).getFile();
        } catch (Exception e) {
            return null;
        }
    }

    /**
     * This method is called upon plug-in activation
     */
    public void start(BundleContext context) throws Exception {
        super.start(context);
    }

    /**
     * This method is called when the plug-in is stopped
     */
    public void stop(BundleContext context) throws Exception {
        super.stop(context);
    }

}